'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var execa = require('execa');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var execa__default = /*#__PURE__*/_interopDefaultLegacy(execa);

const shellCommand = (cmdString) => {
  return () => execa__default["default"].command(cmdString, { stdio: 'inherit' })
};

const runCommands = (userOptions = {}) => {
  const options = {
    once: true,
    runOn: 'writeBundle',
    commands: [],
    ...userOptions
  };
  let runCount = 0;
  const runCountOk = () => !(options.once && runCount > 0);
  const runCommands = async (context, outputOptions, bundle) => {
    ++runCount;
    try {
      for (const commandFunction of options.commands) {
        await commandFunction(outputOptions, bundle);
      }
    } catch (error) {
      context.error(error);
    }
  };
  return {
    name: 'run-commands',
    async generateBundle (outputOptions, bundle) {
      if (options.runOn !== 'writeBundle' && runCountOk()) await runCommands(this, outputOptions, bundle);
    },
    async writeBundle (outputOptions, bundle) {
      if (options.runOn === 'writeBundle' && runCountOk()) await runCommands(this, outputOptions, bundle);
    }
  }
};

exports["default"] = runCommands;
exports.runCommands = runCommands;
exports.shellCommand = shellCommand;
